==> nextcloud-21.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/hr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Želite li dodati udaljeni udjel {name} od {owner} u {remote}?",
    "Remote share" : "Udaljeno dijeljenje",
    "Remote share password" : "Zaporka za udaljeno dijeljenje",
    "Cancel" : "Odustani",
    "Add remote share" : "Dodaj udaljeno dijeljenje",
    "Copy" : "Kopiraj",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "Invalid Federated Cloud ID" : "Nevažeći ID udruženog oblaka",
    "Server to server sharing is not enabled on this server" : "Dijeljenje između poslužitelja nije omogućeno na ovom poslužitelju",
    "Couldn't establish a federated share." : "Nije moguće uspostaviti udruženo dijeljenje.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nije moguće uspostaviti udruženo dijeljenje, možda je pogrešna zaporka.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Poslan je zahtjev za udruženo dijeljenje i primit ćete poziv. Provjerite svoje obavijesti.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nije moguće uspostaviti udruženo dijeljenje, čini se da je poslužitelj s kojim se udružuje prestar (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Nije dopušteno slanje udruženih grupnih dijeljenja s ovog poslužitelja.",
    "Not allowed to create a federated share with the same user" : "Nije dopušteno stvaranje udruženog dijeljenja s istim korisnikom",
    "File is already shared with %s" : "Datoteka je već dijeljena s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Dijeljenje %1$s nije uspjelo, nije bilo moguće pronaći %2$s, možda je poslužitelj trenutno nedostupan ili koristi vjerodajnicu koju je sam potpisao.",
    "Could not find share" : "Nije moguće pronaći dijeljenje",
    "Federated sharing" : "Udruženo dijeljenje",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Primili ste „%3$s” kao udaljeno dijeljenje od %4$s (%1$s) (u ime %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Primili ste {share} kao udaljeno dijeljenje od {user} (u ime {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Primili ste „%3$s” kao udaljeno dijeljenje od %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Primili ste {share} kao udaljeno dijeljenje od {user}",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Dijeli sa mnom putem mog #ID-ja udruženog oblaka Nextclouda, pogledajte %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dijeli sa mnom putem mog #ID-ja udruženog oblaka Nextclouda",
    "Sharing" : "Dijeljenje",
    "Federated file sharing" : "Udruženo dijeljenje datoteka",
    "Provide federated file sharing across servers" : "Omogućite udruženo dijeljenje datoteka između poslužitelja",
    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
    "Open documentation" : "Otvori dokumentaciju",
    "Adjust how people can share between servers." : "Prilagodite kako ljudi mogu dijeliti između poslužitelja.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Dopustite korisnicima na ovom poslužitelju da šalju dijeljenja na druge poslužitelje (ova mogućnost također omogućuje pristup javnim dijeljenjima putem WebDAV-a)",
    "Allow users on this server to receive shares from other servers" : "Dopustite korisnicima na ovom poslužitelju da primaju dijeljenja s drugih poslužitelja",
    "Allow users on this server to send shares to groups on other servers" : "Dopustite korisnicima na ovom poslužitelju da šalju dijeljenja grupama na drugim poslužiteljima",
    "Allow users on this server to receive group shares from other servers" : "Dopustite korisnicima na ovom poslužitelju da primaju grupna dijeljenja s drugih poslužitelja",
    "Search global and public address book for users" : "Pretraži globalni i javni adresar za korisnike",
    "Allow users to publish their data to a global and public address book" : "Dopustite korisnicima da objavljuju svoje podatke u globalnom i javnom adresaru",
    "Federated Cloud" : "Udruženi oblak",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Možete dijeliti sa svima koji upotrebljavaju poslužitelj Nextcloud ili druge poslužitelje i usluge kompatibilne s Open Cloud Mesh (OCM)! Samo unesite njihov Federated Cloud ID u dijaloški okvir za dijeljenje. Primjerice: osoba@cloud.example.com",
    "Your Federated Cloud ID:" : "ID vašeg udruženog oblaka:",
    "Share it so your friends can share files with you:" : "Dijelite ga kako bi vaši prijatelji mogli dijeliti datoteke s vama:",
    "Add to your website" : "Dodajte na svoje web-mjesto",
    "Share with me via Nextcloud" : "Dijelite sa mnom putem Nextclouda",
    "HTML Code:" : "HTML kod:",
    "Allow users on this server to send shares to other servers" : "Dopustite korisnicima na ovom poslužitelju da šalju dijeljenja na druge poslužitelje"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-28.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/hr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Želite li dodati udaljeni udjel {name} od {owner} u {remote}?",
    "Remote share" : "Udaljeno dijeljenje",
    "Remote share password" : "Zaporka za udaljeno dijeljenje",
    "Cancel" : "Odustani",
    "Add remote share" : "Dodaj udaljeno dijeljenje",
    "Invalid Federated Cloud ID" : "Nevažeći ID udruženog oblaka",
    "Server to server sharing is not enabled on this server" : "Dijeljenje između poslužitelja nije omogućeno na ovom poslužitelju",
    "Couldn't establish a federated share." : "Nije moguće uspostaviti udruženo dijeljenje.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nije moguće uspostaviti udruženo dijeljenje, možda je pogrešna zaporka.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Poslan je zahtjev za udruženo dijeljenje i primit ćete poziv. Provjerite svoje obavijesti.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nije moguće uspostaviti udruženo dijeljenje, čini se da je poslužitelj s kojim se udružuje prestar (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Nije dopušteno slanje udruženih grupnih dijeljenja s ovog poslužitelja.",
    "Federated shares require read permissions" : "Udružena dijeljenja zahtjevaju dopuštenja za čitanje",
    "File is already shared with %s" : "Datoteka je već dijeljena s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Dijeljenje %1$s nije uspjelo, nije bilo moguće pronaći %2$s, možda je poslužitelj trenutno nedostupan ili koristi vjerodajnicu koju je sam potpisao.",
    "Could not find share" : "Nije moguće pronaći dijeljenje",
    "Federated sharing" : "Udruženo dijeljenje",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Primili ste {share} kao udaljeno dijeljenje od {user} (u ime {behalf})",
    "You received {share} as a remote share from {user}" : "Primili ste {share} kao udaljeno dijeljenje od {user}",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
    "Sharing" : "Dijeljenje",
    "Federated file sharing" : "Udruženo dijeljenje datoteka",
    "Provide federated file sharing across servers" : "Omogućite udruženo dijeljenje datoteka između poslužitelja",
    "Federated Cloud" : "Udruženi oblak",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Možete dijeliti sa svima koji upotrebljavaju poslužitelj Nextcloud ili druge poslužitelje i usluge kompatibilne s Open Cloud Mesh (OCM)! Samo unesite njihov Federated Cloud ID u dijaloški okvir za dijeljenje. Primjerice: osoba@cloud.example.com",
    "Your Federated Cloud ID:" : "ID vašeg udruženog oblaka:",
    "Share it so your friends can share files with you:" : "Dijelite ga kako bi vaši prijatelji mogli dijeliti datoteke s vama:",
    "Twitter" : "Twitter",
    "Add to your website" : "Dodajte na svoje web-mjesto",
    "Share with me via Nextcloud" : "Dijelite sa mnom putem Nextclouda",
    "HTML Code:" : "HTML kod:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dijeli sa mnom putem mog #ID-ja udruženog oblaka Nextclouda",
    "Copy to clipboard" : "Kopiraj u međuspremnik",
    "Copied!" : "Kopirano!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Dijeljenje %1$s nije uspjelo jer je ova stavka već podijeljena s korisnikom %2$s",
    "Not allowed to create a federated share with the same user" : "Nije dopušteno stvaranje udruženog dijeljenja s istim korisnikom",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Prilagodite način na koji ljudi mogu dijeliti između poslužitelja. To uključuje i dijeljenja među korisnicima na ovom poslužitelju ako upotrebljavaju udruženo dijeljenje.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Dopustite korisnicima na ovom poslužitelju da šalju dijeljenja na druge poslužitelje (ova mogućnost također omogućuje pristup javnim dijeljenjima putem WebDAV-a)",
    "Allow users on this server to receive shares from other servers" : "Dopustite korisnicima na ovom poslužitelju da primaju dijeljenja s drugih poslužitelja",
    "Allow users on this server to send shares to groups on other servers" : "Dopustite korisnicima na ovom poslužitelju da šalju dijeljenja grupama na drugim poslužiteljima",
    "Allow users on this server to receive group shares from other servers" : "Dopustite korisnicima na ovom poslužitelju da primaju grupna dijeljenja s drugih poslužitelja",
    "Search global and public address book for users" : "Pretraži globalni i javni adresar za korisnike",
    "Allow users to publish their data to a global and public address book" : "Dopustite korisnicima da objavljuju svoje podatke u globalnom i javnom adresaru"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
